@@ -12,7 +12,7 @@ fn main() {
     // To use zlib-ng in zlib-compat mode, we have to build libgit2 ourselves.
     if !zlib_ng_compat {
         let mut cfg = pkg_config::Config::new();
-        if let Ok(lib) = cfg.atleast_version("1.0.0").probe("libgit2") {
+        if let Ok(lib) = cfg.atleast_version("1.1.0").probe("libgit2") {
             for include in &lib.include_paths {
                 println!("cargo:root={}", include.display());
             }
@@ -78,6 +78,7 @@ fn main() {
     // when when COMPILE_PCRE8 is not defined, which is the default.
     add_c_files(&mut cfg, "libgit2/deps/pcre");
 
+    cfg.file("libgit2/src/allocators/failalloc.c");
     cfg.file("libgit2/src/allocators/stdalloc.c");
 
     if windows {
@@ -106,6 +107,7 @@ fn main() {
     features.push_str("#ifndef INCLUDE_features_h\n");
     features.push_str("#define INCLUDE_features_h\n");
     features.push_str("#define GIT_THREADS 1\n");
+    features.push_str("#define GIT_TRACE 1\n");
 
     if !target.contains("android") {
         features.push_str("#define GIT_USE_NSEC 1\n");
@@ -182,6 +184,10 @@ fn main() {
         println!("cargo:rustc-link-lib=framework=Security");
         println!("cargo:rustc-link-lib=framework=CoreFoundation");
     }
+
+    rerun_if(Path::new("libgit2/include"));
+    rerun_if(Path::new("libgit2/src"));
+    rerun_if(Path::new("libgit2/deps"));
 }
 
 fn cp_r(from: impl AsRef<Path>, to: impl AsRef<Path>) {
@@ -214,3 +220,13 @@ fn add_c_files(build: &mut cc::Build, path: impl AsRef<Path>) {
         }
     }
 }
+
+fn rerun_if(path: &Path) {
+    if path.is_dir() {
+        for entry in fs::read_dir(path).expect("read_dir") {
+            rerun_if(&entry.expect("entry").path());
+        }
+    } else {
+        println!("cargo:rerun-if-changed={}", path.display());
+    }
+}
